package Qt::Gui::QIconEnginePluginV2;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QIconEnginePluginV2
# file     : QtGui/qiconengineplugin.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QIconEngineFactoryInterfaceV2/;
#our @ISA = qw/Qt::Gui::QIconEngineFactoryInterfaceV2/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QIconEnginePluginV2

=head1 PUBLIC METHODS

=over

=item   QIconEnginePluginV2(QObject * parent)

=item   QIconEnginePluginV2(QObject * parent = 0)

=item   ~QIconEnginePluginV2()

=item  QIconEngineV2 * create(const QString & filename)

=item  QIconEngineV2 * create(const QString & filename = QString())

=item  QStringList keys()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
